@@ -51,12 +51,10 @@ def quadrantmean(data: np.ndarray, x: np.ndarray, y: np.ndarray,
     ny = int(np.floor(max(np.abs(y[0]), np.abs(y[-1])) / dy))
     xnew = np.linspace(-nx * dx, nx * dx, 2 * nx + 1)
     ynew = np.linspace(-ny * dy, ny * dy, 2 * ny + 1)
-    Xnew, Ynew = np.meshgrid(x, y)
-    if quadrants == '13':
-        f = RGI((y, x), data, bounds_error=False, fill_value=np.nan)
-        datanew = f((Ynew, Xnew))
-    elif quadrants == '24':
-        f = RGI((y, -x), data, bounds_error=False, fill_value=np.nan)
+    Xnew, Ynew = np.meshgrid(xnew, ynew)
+    if quadrants in ['13', '24']:
+        s = 1 if quadrants == '13' else -1
+        f = RGI((y, s * x), data, bounds_error=False, fill_value=np.nan)
         datanew = f((Ynew, Xnew))
     else:
         print('quadrants must be \'13\' or \'24\'.')
@@ -65,8 +63,8 @@ def quadrantmean(data: np.ndarray, x: np.ndarray, y: np.ndarray,
 
 
 def RGIxy(y: np.ndarray, x: np.ndarray, data: np.ndarray,
-          yxnew: tuple[np.ndarray, np.ndarray] | None = None
-          ) -> object | np.ndarray:
+          yxnew: tuple[np.ndarray, np.ndarray] | None = None,
+          **kwargs) -> object | np.ndarray:
     """RGI for x and y at each channel.
 
     Args:
@@ -82,9 +80,12 @@ def RGIxy(y: np.ndarray, x: np.ndarray, data: np.ndarray,
         print('data must be 2D, 3D, or 4D.')
         return
 
+    _kw = {'bounds_error': False, 'fill_value': np.nan,
+           'method': 'linear'}
+    _kw.update(kwargs)
     c4d = to4dim(data)
     c4d[np.isnan(c4d)] = 0
-    f = [[RGI((y, x), c2d, bounds_error=False, fill_value=np.nan)
+    f = [[RGI((y, x), c2d, **_kw)
           for c2d in c3d] for c3d in c4d]
     if yxnew is None:
         if len(f) == 1:
@@ -97,8 +98,8 @@ def RGIxy(y: np.ndarray, x: np.ndarray, data: np.ndarray,
 
 
 def RGIxyv(v: np.ndarray, y: np.ndarray, x: np.ndarray, data: np.ndarray,
-           vyxnew: tuple[np.ndarray, np.ndarray, np.ndarray] | None = None
-           ) -> object | np.ndarray:
+           vyxnew: tuple[np.ndarray, np.ndarray, np.ndarray] | None = None,
+           **kwargs) -> object | np.ndarray:
     """RGI in the x-y-v space.
 
     Args:
@@ -115,9 +116,12 @@ def RGIxyv(v: np.ndarray, y: np.ndarray, x: np.ndarray, data: np.ndarray,
         print('data must be 3D or 4D.')
         return
 
+    _kw = {'bounds_error': False, 'fill_value': np.nan,
+           'method': 'linear'}
+    _kw.update(kwargs)
     c4d = to4dim(data)
     c4d[np.isnan(c4d)] = 0
-    f = [RGI((v, y, x), c3d, bounds_error=False, fill_value=np.nan) for c3d in c4d]
+    f = [RGI((v, y, x), c3d, **_kw) for c3d in c4d]
     if vyxnew is None:
         if len(f) == 1:
             f = f[0]
@@ -126,8 +130,8 @@ def RGIxyv(v: np.ndarray, y: np.ndarray, x: np.ndarray, data: np.ndarray,
         return np.squeeze([f3d(tuple(vyxnew)) for f3d in f])
 
 
-def filled2d(data: np.ndarray, x: np.ndarray, y: np.ndarray, n: int = 1
-             ) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+def filled2d(data: np.ndarray, x: np.ndarray, y: np.ndarray, n: int = 1,
+             **kwargs) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
     """Fill 2D data, 1D x, and 1D y by a factor of n using RGI.
 
     Args:
@@ -141,7 +145,8 @@ def filled2d(data: np.ndarray, x: np.ndarray, y: np.ndarray, n: int = 1
     """
     xnew = np.linspace(x[0], x[-1], n * (len(x) - 1) + 1)
     ynew = np.linspace(y[0], y[-1], n * (len(y) - 1) + 1)
-    d = RGIxy(y, x, data, np.meshgrid(ynew, xnew, indexing='ij'))
+    d = RGIxy(y, x, data, np.meshgrid(ynew, xnew, indexing='ij'),
+              **kwargs)
     return d, xnew, ynew
 
 
@@ -230,7 +235,8 @@ class AstroData():
         self.data = np.squeeze(d)
         _, self.v, self.y, self.x = grid
 
-    def centering(self, includexy: bool = True, includev: bool = False):
+    def centering(self, includexy: bool = True, includev: bool = False,
+                  **kwargs):
         """Spatial regridding to set the center at (x,y,v)=(0,0,0).
 
         Args:
@@ -244,11 +250,13 @@ class AstroData():
             vnew = self.v - self.v[np.argmin(np.abs(self.v))]
         if includexy and includev:
             self.data = RGIxyv(self.v, self.y, self.x, self.data,
-                               np.meshgrid(vnew, ynew, xnew, indexing='ij'))
+                               np.meshgrid(vnew, ynew, xnew, indexing='ij'),
+                               **kwargs)
             self.v, self.y, self.x = vnew, ynew, xnew
         elif includexy:
             self.data = RGIxy(self.y, self.x, self.data,
-                              np.meshgrid(ynew, xnew, indexing='ij'))
+                              np.meshgrid(ynew, xnew, indexing='ij'),
+                              **kwargs)
             self.y, self.x = ynew, xnew
         elif includev:
             nx, ny, nv = len(self.x), len(self.y), len(self.v)
@@ -286,7 +294,7 @@ class AstroData():
         self.beam[1] = self.beam[0]
         self.beam[2] = 0
 
-    def deproject(self, pa: float = 0, incl: float = 0):
+    def deproject(self, pa: float = 0, incl: float = 0, **kwargs):
         """Exapnd by a factor of 1/cos(incl) in the direction of pa+90 deg.
 
         Args:
@@ -296,7 +304,7 @@ class AstroData():
         ci = np.cos(np.radians(incl))
         A = np.linalg.multi_dot([Mrot(pa), Mfac(1, ci), Mrot(-pa)])
         yxnew = dot2d(A, np.meshgrid(self.y, self.x, indexing='ij'))
-        self.data = RGIxy(self.y, self.x, self.data, yxnew)
+        self.data = RGIxy(self.y, self.x, self.data, yxnew, **kwargs)
         if None not in self.beam:
             bmaj, bmin, bpa = self.beam
             a, b = np.linalg.multi_dot([Mfac(1/bmaj, 1/bmin), Mrot(pa-bpa),
@@ -494,19 +502,19 @@ class AstroData():
             gfitres = {'best': best, 'error': error}
         return v, prof, gfitres
 
-    def rotate(self, pa: float = 0):
+    def rotate(self, pa: float = 0, **kwargs):
         """Counter clockwise rotation with respect to the center.
 
         Args:
             pa (float, optional): Position angle in the unit of degree. Defaults to 0.
         """
         yxnew = dot2d(Mrot(-pa), np.meshgrid(self.y, self.x, indexing='ij'))
-        self.data = RGIxy(self.y, self.x, self.data, yxnew)
+        self.data = RGIxy(self.y, self.x, self.data, yxnew, **kwargs)
         if self.beam[2] is not None:
             self.beam[2] = self.beam[2] + pa
 
     def slice(self, length: float = 0, pa: float = 0,
-              dx: float | None = None) -> np.ndarray:
+              dx: float | None = None, **kwargs) -> np.ndarray:
         """Get 1D slice with given a length and a position-angle.
 
         Args:
@@ -523,7 +531,7 @@ class AstroData():
         r = np.linspace(-n, n, 2 * n + 1) * dx
         pa_rad = np.radians(pa)
         yg, xg = r * np.cos(pa_rad), r * np.sin(pa_rad)
-        z = RGIxy(self.y, self.x, self.data, (yg, xg))
+        z = RGIxy(self.y, self.x, self.data, (yg, xg), **kwargs)
         return np.array([r, z])
 
     def todict(self) -> dict:
@@ -738,7 +746,7 @@ class AstroFrame():
                                    restfreq=d.restfreq[i], vsys=self.vsys,
                                    pv=self.pv)
                 d.beam[i] = fd.get_beam(dist=self.dist)
-                d.bunit[i] = d.fitsheader[i]['BUNIT']
+                d.bunit[i] = fd.get_header('BUNIT')
             if d.data[i] is not None:
                 d.pv[i] = self.pv
                 d.sigma_org[i] = d.sigma[i]
@@ -749,7 +757,7 @@ class AstroFrame():
                                        vlim=self.vlim, pv=self.pv)
                 if grid[2] is not None and len(grid[2]) > 1 and grid[2][1] < grid[2][0]:
                     d.data[i], grid[2] = d.data[i][::-1], grid[2][::-1]
-                    print('Inverted velocity.')
+                    print('Velocity has been inverted.')
                 d.v = grid[2]
                 grid = grid[:3:2] if self.pv else grid[:2]
                 if self.swapxy:
@@ -786,7 +794,7 @@ class AstroFrame():
                         print('pvpa is not specified. pvpa=bmaj is assumed.')
                     p = np.radians(bpa - d.pvpa[i])
                     b = 1 / np.hypot(np.cos(p) / bmaj, np.sin(p) / bmin)
-                    d.beam[i] = np.array([b, d.v[1] - d.v[0], 0])
+                    d.beam[i] = np.array([d.v[1] - d.v[0], b, 0])
             d.Tb[i] = False
             d.cfactor[i] = 1
             if d.fitsimage[i] is not None:
