@@ -80,9 +80,9 @@ class PlotAxes2D():
         xticklabels (list, optional): Defaults to None.
         yticklabels (list, optional): Defaults to None.
         xticksminor (list or int, optional): If int, int times more than xticks. Defaults to None.
-        yticksminor (list ot int, optional): Defaults to None. If int, int times more than xticks. Defaults to None.
+        yticksminor (list or int, optional): Defaults to None. If int, int times more than xticks. Defaults to None.
         grid (dict, optional): True means merely grid(). Defaults to None.
-        aspect (float, optional): Defaults to None.
+        aspect (dict or float, optional): Defaults to None.
     """
     samexy: bool = True
     loglog: bool | None = None
@@ -99,7 +99,7 @@ class PlotAxes2D():
     xticksminor: list | int = None
     yticksminor: list | int = None
     grid: dict | None = None
-    aspect: float | None = None
+    aspect: dict | float | None = None
 
     def set_xyaxes(self, ax):
         if self.loglog is not None:
@@ -159,7 +159,10 @@ class PlotAxes2D():
         if self.grid is not None:
             ax.grid(**({} if self.grid is True else self.grid))
         if self.aspect is not None:
-            ax.set_aspect(self.aspect)
+            if type(self.aspect) is dict:
+                ax.set_aspect(**self.aspect)
+            else:
+                ax.set_aspect(self.aspect)
 
 
 def set_minmax(data: np.ndarray, stretch: str, stretchscale: float,
@@ -500,8 +503,7 @@ class PlotAstroData(AstroFrame):
                 bp = [a, 0.1 if self.pv else a]
             if self.swapxy:
                 bp = np.transpose(bp)
-                if self.pv:
-                    bmaj, bmin = bmin, bmaj
+                bpa = 90 - bpa
             self.add_region(patch=patch, poslist=bp,
                             majlist=bmaj, minlist=bmin, palist=bpa,
                             include_chan=include_chan,
@@ -962,9 +964,9 @@ class PlotAstroData(AstroFrame):
         def makegrid(second, mode):
             second = float(second)
             if mode == 'ra':
-                scale, factor, sec = 1.5, 15 * np.cos(dec), r'$^{\rm s}$'
+                scale, factor, sec = 1.5, 15 * np.cos(dec), r'$^\mathrm{s}$'
             else:
-                scale, factor, sec = 0.5, 1, r'$^{\rm \prime\prime}$'
+                scale, factor, sec = 0.5, 1, r'$^{\prime\prime}$'
             sec = r'.$\hspace{-0.4}$' + sec
             dorder = log2r - scale - (order := np.floor(log2r - scale))
             if 0.00 < dorder <= 0.33:
@@ -996,7 +998,7 @@ class PlotAstroData(AstroFrame):
         yticks, yticksminor, yticklabels = makegrid(dec_s, 'dec')
         ra_hm = get_hmdm(xy2coord([xticks[3] / 3600., 0], center), 0)
         dec_dm = get_hmdm(xy2coord([0, yticks[3] / 3600.], center), 1)
-        ra_hm = ra_hm.replace('h', r'$^{\rm h}$') + r'$^{\rm m}$'
+        ra_hm = ra_hm.replace('h', r'$^\mathrm{h}$') + r'$^\mathrm{m}$'
         dec_dm = dec_dm.replace('d', r'$^{\circ}$') + r'$^{\prime}$'
         xticklabels[3] = ra_hm + xticklabels[3]
         yticklabels[3] = dec_dm + '\n' + yticklabels[3]
